---
title: Overview
page_title: Overview | Kendo UI Barcodes for Vue
description: "Use the Kendo UI components for Vue which are delivered by the Barcodes package."
slug: overview_barcodes
position: 0
---

# Barcodes Overview

The Kendo UI Barcodes for Vue package includes the Barcode and QRCode widgets.

# Installation

To initialize the Barcodes, either:

* [Use the CDN service](#toc-initializing-from-cdn), or
* [Use Webpack](#toc-initializing-with-webpack).

### Initializing from CDN

The following example demonstrates how to initialize the Barcode and QRCode components by using the CDN services. To access all CDN references, open the sample as Plunker.

{% meta height:430 %}
```html-preview
<div id="vueapp" class="vue-app">
	<h4>Barcode</h4>
	<kendo-barcode :value="'Mascarpone'"
				   :type="'code128'"
				   :width="280"
				   :height="100">
	</kendo-barcode>
	
	<h4>QRCode</h4>
	<kendo-qrcode :value="'geo:42.65049,23.37925,100'" 
	              :error-collection="'H'" 
				  :size="120" 
				  :color="'#166a83'">
	</kendo-qrcode>
</div>
```
```js
Vue.use(BarcodesInstaller);

new Vue({
    el: '#vueapp'
})
```
{% endmeta %}

### Initializing with Webpack

1. Install Kendo UI and add a theme:
```sh
npm install --save @progress/kendo-ui
npm install --save @progress/kendo-theme-default
```

1. Install the Kendo UI for Vue Barcodes package:
```sh
npm install --save @progress/kendo-barcodes-vue-wrapper
```

1. Import the Kendo UI packages to the App component. Add all Kendo UI-related files either to the main.js file if you will use them in several places in your application or to another component where they will be used.
    ```js-no-run
    import '@progress/kendo-ui'
    import '@progress/kendo-theme-default/dist/all.css'

	import { Barcode,
             QRCode,
             BarcodesInstaller } from '@progress/kendo-barcodes-vue-wrapper'

    Vue.use(BarcodesInstaller)

    new Vue({
        el: '#app',
        components: {
            Barcode,
			QRCode
        }
    })
```

## Features

* All Barcode graphics are rendered on the client by using Scalable Vector Graphics (SVG).
* Barcode support for different symbologies.
* Different conventions support for QRCode values.
* QRCode graphics rendered using HTML5 Canvas or SVG.
* QRCode fallback to VML for older browsers.


## Suggested Links

* [API Reference of Barcode](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/qrcode)
* [API Reference of QRCode](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/qrcode)
